#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayGongyiAddressTest import AlipayGongyiAddressTest
from alipay.aop.api.domain.OuterShopDO import OuterShopDO
from alipay.aop.api.domain.AlipayGongyiModelTest import AlipayGongyiModelTest


class AlipayOpenAppGongyiTestQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppGongyiTestQueryResponse, self).__init__()
        self._createdate = None
        self._shopaddress = None
        self._shopinfo = None
        self._shopname = None
        self._shoprecord = None

    @property
    def createdate(self):
        return self._createdate

    @createdate.setter
    def createdate(self, value):
        self._createdate = value
    @property
    def shopaddress(self):
        return self._shopaddress

    @shopaddress.setter
    def shopaddress(self, value):
        if isinstance(value, AlipayGongyiAddressTest):
            self._shopaddress = value
        else:
            self._shopaddress = AlipayGongyiAddressTest.from_alipay_dict(value)
    @property
    def shopinfo(self):
        return self._shopinfo

    @shopinfo.setter
    def shopinfo(self, value):
        if isinstance(value, OuterShopDO):
            self._shopinfo = value
        else:
            self._shopinfo = OuterShopDO.from_alipay_dict(value)
    @property
    def shopname(self):
        return self._shopname

    @shopname.setter
    def shopname(self, value):
        self._shopname = value
    @property
    def shoprecord(self):
        return self._shoprecord

    @shoprecord.setter
    def shoprecord(self, value):
        if isinstance(value, AlipayGongyiModelTest):
            self._shoprecord = value
        else:
            self._shoprecord = AlipayGongyiModelTest.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppGongyiTestQueryResponse, self).parse_response_content(response_content)
        if 'createdate' in response:
            self.createdate = response['createdate']
        if 'shopaddress' in response:
            self.shopaddress = response['shopaddress']
        if 'shopinfo' in response:
            self.shopinfo = response['shopinfo']
        if 'shopname' in response:
            self.shopname = response['shopname']
        if 'shoprecord' in response:
            self.shoprecord = response['shoprecord']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BelongGreenMerchantInfo import BelongGreenMerchantInfo


class AlipayCommerceGreenItemUploadModel(object):

    def __init__(self):
        self._belong_merchant_info = None
        self._data_operation = None
        self._goods_id = None
        self._goods_name = None
        self._qr_code_list = None
        self._upload_time = None

    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, BelongGreenMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = BelongGreenMerchantInfo.from_alipay_dict(value)
    @property
    def data_operation(self):
        return self._data_operation

    @data_operation.setter
    def data_operation(self, value):
        self._data_operation = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def qr_code_list(self):
        return self._qr_code_list

    @qr_code_list.setter
    def qr_code_list(self, value):
        if isinstance(value, list):
            self._qr_code_list = list()
            for i in value:
                self._qr_code_list.append(i)
    @property
    def upload_time(self):
        return self._upload_time

    @upload_time.setter
    def upload_time(self, value):
        self._upload_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.data_operation:
            if hasattr(self.data_operation, 'to_alipay_dict'):
                params['data_operation'] = self.data_operation.to_alipay_dict()
            else:
                params['data_operation'] = self.data_operation
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.qr_code_list:
            if isinstance(self.qr_code_list, list):
                for i in range(0, len(self.qr_code_list)):
                    element = self.qr_code_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.qr_code_list[i] = element.to_alipay_dict()
            if hasattr(self.qr_code_list, 'to_alipay_dict'):
                params['qr_code_list'] = self.qr_code_list.to_alipay_dict()
            else:
                params['qr_code_list'] = self.qr_code_list
        if self.upload_time:
            if hasattr(self.upload_time, 'to_alipay_dict'):
                params['upload_time'] = self.upload_time.to_alipay_dict()
            else:
                params['upload_time'] = self.upload_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceGreenItemUploadModel()
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'data_operation' in d:
            o.data_operation = d['data_operation']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'qr_code_list' in d:
            o.qr_code_list = d['qr_code_list']
        if 'upload_time' in d:
            o.upload_time = d['upload_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainFinanceMylogisticfinsysMessagePublishResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainFinanceMylogisticfinsysMessagePublishResponse, self).__init__()
        self._data = None
        self._extra_info = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def extra_info(self):
        return self._extra_info

    @extra_info.setter
    def extra_info(self, value):
        self._extra_info = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainFinanceMylogisticfinsysMessagePublishResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'extra_info' in response:
            self.extra_info = response['extra_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FvPairList import FvPairList


class MdRecord(object):

    def __init__(self):
        self._data_struct = None
        self._dicode = None
        self._diname = None
        self._dynamic_fields = None
        self._gmt_modified = None
        self._id = None
        self._memo = None
        self._multi_parents = None

    @property
    def data_struct(self):
        return self._data_struct

    @data_struct.setter
    def data_struct(self, value):
        self._data_struct = value
    @property
    def dicode(self):
        return self._dicode

    @dicode.setter
    def dicode(self, value):
        self._dicode = value
    @property
    def diname(self):
        return self._diname

    @diname.setter
    def diname(self, value):
        self._diname = value
    @property
    def dynamic_fields(self):
        return self._dynamic_fields

    @dynamic_fields.setter
    def dynamic_fields(self, value):
        if isinstance(value, list):
            self._dynamic_fields = list()
            for i in value:
                if isinstance(i, FvPairList):
                    self._dynamic_fields.append(i)
                else:
                    self._dynamic_fields.append(FvPairList.from_alipay_dict(i))
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def multi_parents(self):
        return self._multi_parents

    @multi_parents.setter
    def multi_parents(self, value):
        if isinstance(value, list):
            self._multi_parents = list()
            for i in value:
                self._multi_parents.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.data_struct:
            if hasattr(self.data_struct, 'to_alipay_dict'):
                params['data_struct'] = self.data_struct.to_alipay_dict()
            else:
                params['data_struct'] = self.data_struct
        if self.dicode:
            if hasattr(self.dicode, 'to_alipay_dict'):
                params['dicode'] = self.dicode.to_alipay_dict()
            else:
                params['dicode'] = self.dicode
        if self.diname:
            if hasattr(self.diname, 'to_alipay_dict'):
                params['diname'] = self.diname.to_alipay_dict()
            else:
                params['diname'] = self.diname
        if self.dynamic_fields:
            if isinstance(self.dynamic_fields, list):
                for i in range(0, len(self.dynamic_fields)):
                    element = self.dynamic_fields[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dynamic_fields[i] = element.to_alipay_dict()
            if hasattr(self.dynamic_fields, 'to_alipay_dict'):
                params['dynamic_fields'] = self.dynamic_fields.to_alipay_dict()
            else:
                params['dynamic_fields'] = self.dynamic_fields
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.multi_parents:
            if isinstance(self.multi_parents, list):
                for i in range(0, len(self.multi_parents)):
                    element = self.multi_parents[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.multi_parents[i] = element.to_alipay_dict()
            if hasattr(self.multi_parents, 'to_alipay_dict'):
                params['multi_parents'] = self.multi_parents.to_alipay_dict()
            else:
                params['multi_parents'] = self.multi_parents
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MdRecord()
        if 'data_struct' in d:
            o.data_struct = d['data_struct']
        if 'dicode' in d:
            o.dicode = d['dicode']
        if 'diname' in d:
            o.diname = d['diname']
        if 'dynamic_fields' in d:
            o.dynamic_fields = d['dynamic_fields']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'multi_parents' in d:
            o.multi_parents = d['multi_parents']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankPaymentTradeDepositVerifyApplyModel(object):

    def __init__(self):
        self._bank_card_name = None
        self._bank_card_no = None
        self._bank_code = None
        self._callback_url = None
        self._credit_code = None
        self._legal_person_cert_no = None
        self._legal_person_cert_type = None
        self._legal_person_name = None
        self._member_id = None
        self._mobile = None
        self._request_no = None
        self._scene = None

    @property
    def bank_card_name(self):
        return self._bank_card_name

    @bank_card_name.setter
    def bank_card_name(self, value):
        self._bank_card_name = value
    @property
    def bank_card_no(self):
        return self._bank_card_no

    @bank_card_no.setter
    def bank_card_no(self, value):
        self._bank_card_no = value
    @property
    def bank_code(self):
        return self._bank_code

    @bank_code.setter
    def bank_code(self, value):
        self._bank_code = value
    @property
    def callback_url(self):
        return self._callback_url

    @callback_url.setter
    def callback_url(self, value):
        self._callback_url = value
    @property
    def credit_code(self):
        return self._credit_code

    @credit_code.setter
    def credit_code(self, value):
        self._credit_code = value
    @property
    def legal_person_cert_no(self):
        return self._legal_person_cert_no

    @legal_person_cert_no.setter
    def legal_person_cert_no(self, value):
        self._legal_person_cert_no = value
    @property
    def legal_person_cert_type(self):
        return self._legal_person_cert_type

    @legal_person_cert_type.setter
    def legal_person_cert_type(self, value):
        self._legal_person_cert_type = value
    @property
    def legal_person_name(self):
        return self._legal_person_name

    @legal_person_name.setter
    def legal_person_name(self, value):
        self._legal_person_name = value
    @property
    def member_id(self):
        return self._member_id

    @member_id.setter
    def member_id(self, value):
        self._member_id = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_card_name:
            if hasattr(self.bank_card_name, 'to_alipay_dict'):
                params['bank_card_name'] = self.bank_card_name.to_alipay_dict()
            else:
                params['bank_card_name'] = self.bank_card_name
        if self.bank_card_no:
            if hasattr(self.bank_card_no, 'to_alipay_dict'):
                params['bank_card_no'] = self.bank_card_no.to_alipay_dict()
            else:
                params['bank_card_no'] = self.bank_card_no
        if self.bank_code:
            if hasattr(self.bank_code, 'to_alipay_dict'):
                params['bank_code'] = self.bank_code.to_alipay_dict()
            else:
                params['bank_code'] = self.bank_code
        if self.callback_url:
            if hasattr(self.callback_url, 'to_alipay_dict'):
                params['callback_url'] = self.callback_url.to_alipay_dict()
            else:
                params['callback_url'] = self.callback_url
        if self.credit_code:
            if hasattr(self.credit_code, 'to_alipay_dict'):
                params['credit_code'] = self.credit_code.to_alipay_dict()
            else:
                params['credit_code'] = self.credit_code
        if self.legal_person_cert_no:
            if hasattr(self.legal_person_cert_no, 'to_alipay_dict'):
                params['legal_person_cert_no'] = self.legal_person_cert_no.to_alipay_dict()
            else:
                params['legal_person_cert_no'] = self.legal_person_cert_no
        if self.legal_person_cert_type:
            if hasattr(self.legal_person_cert_type, 'to_alipay_dict'):
                params['legal_person_cert_type'] = self.legal_person_cert_type.to_alipay_dict()
            else:
                params['legal_person_cert_type'] = self.legal_person_cert_type
        if self.legal_person_name:
            if hasattr(self.legal_person_name, 'to_alipay_dict'):
                params['legal_person_name'] = self.legal_person_name.to_alipay_dict()
            else:
                params['legal_person_name'] = self.legal_person_name
        if self.member_id:
            if hasattr(self.member_id, 'to_alipay_dict'):
                params['member_id'] = self.member_id.to_alipay_dict()
            else:
                params['member_id'] = self.member_id
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.request_no:
            if hasattr(self.request_no, 'to_alipay_dict'):
                params['request_no'] = self.request_no.to_alipay_dict()
            else:
                params['request_no'] = self.request_no
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeDepositVerifyApplyModel()
        if 'bank_card_name' in d:
            o.bank_card_name = d['bank_card_name']
        if 'bank_card_no' in d:
            o.bank_card_no = d['bank_card_no']
        if 'bank_code' in d:
            o.bank_code = d['bank_code']
        if 'callback_url' in d:
            o.callback_url = d['callback_url']
        if 'credit_code' in d:
            o.credit_code = d['credit_code']
        if 'legal_person_cert_no' in d:
            o.legal_person_cert_no = d['legal_person_cert_no']
        if 'legal_person_cert_type' in d:
            o.legal_person_cert_type = d['legal_person_cert_type']
        if 'legal_person_name' in d:
            o.legal_person_name = d['legal_person_name']
        if 'member_id' in d:
            o.member_id = d['member_id']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'request_no' in d:
            o.request_no = d['request_no']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BusinessPermission import BusinessPermission


class KoubeiMerchantRoleDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMerchantRoleDetailQueryResponse, self).__init__()
        self._permissions = None
        self._role_code = None
        self._role_id = None
        self._role_name = None

    @property
    def permissions(self):
        return self._permissions

    @permissions.setter
    def permissions(self, value):
        if isinstance(value, list):
            self._permissions = list()
            for i in value:
                if isinstance(i, BusinessPermission):
                    self._permissions.append(i)
                else:
                    self._permissions.append(BusinessPermission.from_alipay_dict(i))
    @property
    def role_code(self):
        return self._role_code

    @role_code.setter
    def role_code(self, value):
        self._role_code = value
    @property
    def role_id(self):
        return self._role_id

    @role_id.setter
    def role_id(self, value):
        self._role_id = value
    @property
    def role_name(self):
        return self._role_name

    @role_name.setter
    def role_name(self, value):
        self._role_name = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMerchantRoleDetailQueryResponse, self).parse_response_content(response_content)
        if 'permissions' in response:
            self.permissions = response['permissions']
        if 'role_code' in response:
            self.role_code = response['role_code']
        if 'role_id' in response:
            self.role_id = response['role_id']
        if 'role_name' in response:
            self.role_name = response['role_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccessReturnQrcode(object):

    def __init__(self):
        self._asset_purchase_id = None
        self._express_no = None
        self._out_biz_no = None
        self._qrcode = None

    @property
    def asset_purchase_id(self):
        return self._asset_purchase_id

    @asset_purchase_id.setter
    def asset_purchase_id(self, value):
        self._asset_purchase_id = value
    @property
    def express_no(self):
        return self._express_no

    @express_no.setter
    def express_no(self, value):
        self._express_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def qrcode(self):
        return self._qrcode

    @qrcode.setter
    def qrcode(self, value):
        self._qrcode = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_purchase_id:
            if hasattr(self.asset_purchase_id, 'to_alipay_dict'):
                params['asset_purchase_id'] = self.asset_purchase_id.to_alipay_dict()
            else:
                params['asset_purchase_id'] = self.asset_purchase_id
        if self.express_no:
            if hasattr(self.express_no, 'to_alipay_dict'):
                params['express_no'] = self.express_no.to_alipay_dict()
            else:
                params['express_no'] = self.express_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.qrcode:
            if hasattr(self.qrcode, 'to_alipay_dict'):
                params['qrcode'] = self.qrcode.to_alipay_dict()
            else:
                params['qrcode'] = self.qrcode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccessReturnQrcode()
        if 'asset_purchase_id' in d:
            o.asset_purchase_id = d['asset_purchase_id']
        if 'express_no' in d:
            o.express_no = d['express_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'qrcode' in d:
            o.qrcode = d['qrcode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AccountVO import AccountVO


class AnttechBlockchainDefinSaasAccountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinSaasAccountQueryResponse, self).__init__()
        self._accounts = None
        self._out_member_id = None

    @property
    def accounts(self):
        return self._accounts

    @accounts.setter
    def accounts(self, value):
        if isinstance(value, list):
            self._accounts = list()
            for i in value:
                if isinstance(i, AccountVO):
                    self._accounts.append(i)
                else:
                    self._accounts.append(AccountVO.from_alipay_dict(i))
    @property
    def out_member_id(self):
        return self._out_member_id

    @out_member_id.setter
    def out_member_id(self, value):
        self._out_member_id = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinSaasAccountQueryResponse, self).parse_response_content(response_content)
        if 'accounts' in response:
            self.accounts = response['accounts']
        if 'out_member_id' in response:
            self.out_member_id = response['out_member_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BPaaSServiceInfo import BPaaSServiceInfo


class AlipayOpenBpaasServiceQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenBpaasServiceQueryResponse, self).__init__()
        self._service_list = None

    @property
    def service_list(self):
        return self._service_list

    @service_list.setter
    def service_list(self, value):
        if isinstance(value, list):
            self._service_list = list()
            for i in value:
                if isinstance(i, BPaaSServiceInfo):
                    self._service_list.append(i)
                else:
                    self._service_list.append(BPaaSServiceInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenBpaasServiceQueryResponse, self).parse_response_content(response_content)
        if 'service_list' in response:
            self.service_list = response['service_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OperateTask(object):

    def __init__(self):
        self._operation_params = None
        self._operation_type = None
        self._task_id = None

    @property
    def operation_params(self):
        return self._operation_params

    @operation_params.setter
    def operation_params(self, value):
        self._operation_params = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.operation_params:
            if hasattr(self.operation_params, 'to_alipay_dict'):
                params['operation_params'] = self.operation_params.to_alipay_dict()
            else:
                params['operation_params'] = self.operation_params
        if self.operation_type:
            if hasattr(self.operation_type, 'to_alipay_dict'):
                params['operation_type'] = self.operation_type.to_alipay_dict()
            else:
                params['operation_type'] = self.operation_type
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OperateTask()
        if 'operation_params' in d:
            o.operation_params = d['operation_params']
        if 'operation_type' in d:
            o.operation_type = d['operation_type']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NearbyCrowdDensity(object):

    def __init__(self):
        self._crowd_density = None
        self._geohash = None

    @property
    def crowd_density(self):
        return self._crowd_density

    @crowd_density.setter
    def crowd_density(self, value):
        self._crowd_density = value
    @property
    def geohash(self):
        return self._geohash

    @geohash.setter
    def geohash(self, value):
        self._geohash = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_density:
            if hasattr(self.crowd_density, 'to_alipay_dict'):
                params['crowd_density'] = self.crowd_density.to_alipay_dict()
            else:
                params['crowd_density'] = self.crowd_density
        if self.geohash:
            if hasattr(self.geohash, 'to_alipay_dict'):
                params['geohash'] = self.geohash.to_alipay_dict()
            else:
                params['geohash'] = self.geohash
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NearbyCrowdDensity()
        if 'crowd_density' in d:
            o.crowd_density = d['crowd_density']
        if 'geohash' in d:
            o.geohash = d['geohash']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainFinancePfQuotaQueryModel(object):

    def __init__(self):
        self._client_no = None
        self._crf_type = None
        self._id_num = None
        self._parm = None
        self._platform_id = None

    @property
    def client_no(self):
        return self._client_no

    @client_no.setter
    def client_no(self, value):
        self._client_no = value
    @property
    def crf_type(self):
        return self._crf_type

    @crf_type.setter
    def crf_type(self, value):
        self._crf_type = value
    @property
    def id_num(self):
        return self._id_num

    @id_num.setter
    def id_num(self, value):
        self._id_num = value
    @property
    def parm(self):
        return self._parm

    @parm.setter
    def parm(self, value):
        self._parm = value
    @property
    def platform_id(self):
        return self._platform_id

    @platform_id.setter
    def platform_id(self, value):
        self._platform_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.client_no:
            if hasattr(self.client_no, 'to_alipay_dict'):
                params['client_no'] = self.client_no.to_alipay_dict()
            else:
                params['client_no'] = self.client_no
        if self.crf_type:
            if hasattr(self.crf_type, 'to_alipay_dict'):
                params['crf_type'] = self.crf_type.to_alipay_dict()
            else:
                params['crf_type'] = self.crf_type
        if self.id_num:
            if hasattr(self.id_num, 'to_alipay_dict'):
                params['id_num'] = self.id_num.to_alipay_dict()
            else:
                params['id_num'] = self.id_num
        if self.parm:
            if hasattr(self.parm, 'to_alipay_dict'):
                params['parm'] = self.parm.to_alipay_dict()
            else:
                params['parm'] = self.parm
        if self.platform_id:
            if hasattr(self.platform_id, 'to_alipay_dict'):
                params['platform_id'] = self.platform_id.to_alipay_dict()
            else:
                params['platform_id'] = self.platform_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinancePfQuotaQueryModel()
        if 'client_no' in d:
            o.client_no = d['client_no']
        if 'crf_type' in d:
            o.crf_type = d['crf_type']
        if 'id_num' in d:
            o.id_num = d['id_num']
        if 'parm' in d:
            o.parm = d['parm']
        if 'platform_id' in d:
            o.platform_id = d['platform_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Signer import Signer


class SignField(object):

    def __init__(self):
        self._auto_execute = None
        self._signer = None
        self._struct_key = None

    @property
    def auto_execute(self):
        return self._auto_execute

    @auto_execute.setter
    def auto_execute(self, value):
        self._auto_execute = value
    @property
    def signer(self):
        return self._signer

    @signer.setter
    def signer(self, value):
        if isinstance(value, Signer):
            self._signer = value
        else:
            self._signer = Signer.from_alipay_dict(value)
    @property
    def struct_key(self):
        return self._struct_key

    @struct_key.setter
    def struct_key(self, value):
        self._struct_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.auto_execute:
            if hasattr(self.auto_execute, 'to_alipay_dict'):
                params['auto_execute'] = self.auto_execute.to_alipay_dict()
            else:
                params['auto_execute'] = self.auto_execute
        if self.signer:
            if hasattr(self.signer, 'to_alipay_dict'):
                params['signer'] = self.signer.to_alipay_dict()
            else:
                params['signer'] = self.signer
        if self.struct_key:
            if hasattr(self.struct_key, 'to_alipay_dict'):
                params['struct_key'] = self.struct_key.to_alipay_dict()
            else:
                params['struct_key'] = self.struct_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignField()
        if 'auto_execute' in d:
            o.auto_execute = d['auto_execute']
        if 'signer' in d:
            o.signer = d['signer']
        if 'struct_key' in d:
            o.struct_key = d['struct_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoMycarParkingPayRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarParkingPayRefundResponse, self).__init__()
        self._biz_code = None
        self._biz_msg = None
        self._out_order_no = None
        self._out_refund_no = None
        self._parking_order_no = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_msg(self):
        return self._biz_msg

    @biz_msg.setter
    def biz_msg(self, value):
        self._biz_msg = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_refund_no(self):
        return self._out_refund_no

    @out_refund_no.setter
    def out_refund_no(self, value):
        self._out_refund_no = value
    @property
    def parking_order_no(self):
        return self._parking_order_no

    @parking_order_no.setter
    def parking_order_no(self, value):
        self._parking_order_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarParkingPayRefundResponse, self).parse_response_content(response_content)
        if 'biz_code' in response:
            self.biz_code = response['biz_code']
        if 'biz_msg' in response:
            self.biz_msg = response['biz_msg']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'out_refund_no' in response:
            self.out_refund_no = response['out_refund_no']
        if 'parking_order_no' in response:
            self.parking_order_no = response['parking_order_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.GavintestNewLeveaOne import GavintestNewLeveaOne


class AlipayOpenDesCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenDesCreateResponse, self).__init__()
        self._ces = None

    @property
    def ces(self):
        return self._ces

    @ces.setter
    def ces(self, value):
        if isinstance(value, GavintestNewLeveaOne):
            self._ces = value
        else:
            self._ces = GavintestNewLeveaOne.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenDesCreateResponse, self).parse_response_content(response_content)
        if 'ces' in response:
            self.ces = response['ces']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PrizeInfo import PrizeInfo


class AlipayOverseasTravelGkaCampaignApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTravelGkaCampaignApplyResponse, self).__init__()
        self._prize_info = None
        self._result_code = None
        self._result_msg = None

    @property
    def prize_info(self):
        return self._prize_info

    @prize_info.setter
    def prize_info(self, value):
        if isinstance(value, PrizeInfo):
            self._prize_info = value
        else:
            self._prize_info = PrizeInfo.from_alipay_dict(value)
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTravelGkaCampaignApplyResponse, self).parse_response_content(response_content)
        if 'prize_info' in response:
            self.prize_info = response['prize_info']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoLogisticsExpressPriceQueryModel(object):

    def __init__(self):
        self._area_type = None
        self._from_code = None
        self._logis_merch_code = None
        self._product_type_code = None
        self._to_code = None

    @property
    def area_type(self):
        return self._area_type

    @area_type.setter
    def area_type(self, value):
        self._area_type = value
    @property
    def from_code(self):
        return self._from_code

    @from_code.setter
    def from_code(self, value):
        self._from_code = value
    @property
    def logis_merch_code(self):
        return self._logis_merch_code

    @logis_merch_code.setter
    def logis_merch_code(self, value):
        self._logis_merch_code = value
    @property
    def product_type_code(self):
        return self._product_type_code

    @product_type_code.setter
    def product_type_code(self, value):
        self._product_type_code = value
    @property
    def to_code(self):
        return self._to_code

    @to_code.setter
    def to_code(self, value):
        self._to_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_type:
            if hasattr(self.area_type, 'to_alipay_dict'):
                params['area_type'] = self.area_type.to_alipay_dict()
            else:
                params['area_type'] = self.area_type
        if self.from_code:
            if hasattr(self.from_code, 'to_alipay_dict'):
                params['from_code'] = self.from_code.to_alipay_dict()
            else:
                params['from_code'] = self.from_code
        if self.logis_merch_code:
            if hasattr(self.logis_merch_code, 'to_alipay_dict'):
                params['logis_merch_code'] = self.logis_merch_code.to_alipay_dict()
            else:
                params['logis_merch_code'] = self.logis_merch_code
        if self.product_type_code:
            if hasattr(self.product_type_code, 'to_alipay_dict'):
                params['product_type_code'] = self.product_type_code.to_alipay_dict()
            else:
                params['product_type_code'] = self.product_type_code
        if self.to_code:
            if hasattr(self.to_code, 'to_alipay_dict'):
                params['to_code'] = self.to_code.to_alipay_dict()
            else:
                params['to_code'] = self.to_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoLogisticsExpressPriceQueryModel()
        if 'area_type' in d:
            o.area_type = d['area_type']
        if 'from_code' in d:
            o.from_code = d['from_code']
        if 'logis_merch_code' in d:
            o.logis_merch_code = d['logis_merch_code']
        if 'product_type_code' in d:
            o.product_type_code = d['product_type_code']
        if 'to_code' in d:
            o.to_code = d['to_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InvoiceItemContent import InvoiceItemContent


class AlipayEbppInvoiceDetailOutputQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceDetailOutputQueryResponse, self).__init__()
        self._anti_fake_code = None
        self._ex_tax_amount = None
        self._expense_status = None
        self._has_risk = None
        self._has_upload_pdf = None
        self._invoice_amount = None
        self._invoice_code = None
        self._invoice_date = None
        self._invoice_img_url = None
        self._invoice_item_content_list = None
        self._invoice_no = None
        self._invoice_status = None
        self._invoice_type = None
        self._payee_address = None
        self._payee_bank_account = None
        self._payee_bank_name = None
        self._payee_phone = None
        self._payee_register_name = None
        self._payee_tax_no = None
        self._payer_address = None
        self._payer_bank_account = None
        self._payer_bank_name = None
        self._payer_name = None
        self._payer_phone = None
        self._payer_tax_no = None
        self._sum_tax_amount = None
        self._tax_type = None

    @property
    def anti_fake_code(self):
        return self._anti_fake_code

    @anti_fake_code.setter
    def anti_fake_code(self, value):
        self._anti_fake_code = value
    @property
    def ex_tax_amount(self):
        return self._ex_tax_amount

    @ex_tax_amount.setter
    def ex_tax_amount(self, value):
        self._ex_tax_amount = value
    @property
    def expense_status(self):
        return self._expense_status

    @expense_status.setter
    def expense_status(self, value):
        self._expense_status = value
    @property
    def has_risk(self):
        return self._has_risk

    @has_risk.setter
    def has_risk(self, value):
        self._has_risk = value
    @property
    def has_upload_pdf(self):
        return self._has_upload_pdf

    @has_upload_pdf.setter
    def has_upload_pdf(self, value):
        self._has_upload_pdf = value
    @property
    def invoice_amount(self):
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, value):
        self._invoice_amount = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_img_url(self):
        return self._invoice_img_url

    @invoice_img_url.setter
    def invoice_img_url(self, value):
        self._invoice_img_url = value
    @property
    def invoice_item_content_list(self):
        return self._invoice_item_content_list

    @invoice_item_content_list.setter
    def invoice_item_content_list(self, value):
        if isinstance(value, list):
            self._invoice_item_content_list = list()
            for i in value:
                if isinstance(i, InvoiceItemContent):
                    self._invoice_item_content_list.append(i)
                else:
                    self._invoice_item_content_list.append(InvoiceItemContent.from_alipay_dict(i))
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_status(self):
        return self._invoice_status

    @invoice_status.setter
    def invoice_status(self, value):
        self._invoice_status = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def payee_address(self):
        return self._payee_address

    @payee_address.setter
    def payee_address(self, value):
        self._payee_address = value
    @property
    def payee_bank_account(self):
        return self._payee_bank_account

    @payee_bank_account.setter
    def payee_bank_account(self, value):
        self._payee_bank_account = value
    @property
    def payee_bank_name(self):
        return self._payee_bank_name

    @payee_bank_name.setter
    def payee_bank_name(self, value):
        self._payee_bank_name = value
    @property
    def payee_phone(self):
        return self._payee_phone

    @payee_phone.setter
    def payee_phone(self, value):
        self._payee_phone = value
    @property
    def payee_register_name(self):
        return self._payee_register_name

    @payee_register_name.setter
    def payee_register_name(self, value):
        self._payee_register_name = value
    @property
    def payee_tax_no(self):
        return self._payee_tax_no

    @payee_tax_no.setter
    def payee_tax_no(self, value):
        self._payee_tax_no = value
    @property
    def payer_address(self):
        return self._payer_address

    @payer_address.setter
    def payer_address(self, value):
        self._payer_address = value
    @property
    def payer_bank_account(self):
        return self._payer_bank_account

    @payer_bank_account.setter
    def payer_bank_account(self, value):
        self._payer_bank_account = value
    @property
    def payer_bank_name(self):
        return self._payer_bank_name

    @payer_bank_name.setter
    def payer_bank_name(self, value):
        self._payer_bank_name = value
    @property
    def payer_name(self):
        return self._payer_name

    @payer_name.setter
    def payer_name(self, value):
        self._payer_name = value
    @property
    def payer_phone(self):
        return self._payer_phone

    @payer_phone.setter
    def payer_phone(self, value):
        self._payer_phone = value
    @property
    def payer_tax_no(self):
        return self._payer_tax_no

    @payer_tax_no.setter
    def payer_tax_no(self, value):
        self._payer_tax_no = value
    @property
    def sum_tax_amount(self):
        return self._sum_tax_amount

    @sum_tax_amount.setter
    def sum_tax_amount(self, value):
        self._sum_tax_amount = value
    @property
    def tax_type(self):
        return self._tax_type

    @tax_type.setter
    def tax_type(self, value):
        self._tax_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceDetailOutputQueryResponse, self).parse_response_content(response_content)
        if 'anti_fake_code' in response:
            self.anti_fake_code = response['anti_fake_code']
        if 'ex_tax_amount' in response:
            self.ex_tax_amount = response['ex_tax_amount']
        if 'expense_status' in response:
            self.expense_status = response['expense_status']
        if 'has_risk' in response:
            self.has_risk = response['has_risk']
        if 'has_upload_pdf' in response:
            self.has_upload_pdf = response['has_upload_pdf']
        if 'invoice_amount' in response:
            self.invoice_amount = response['invoice_amount']
        if 'invoice_code' in response:
            self.invoice_code = response['invoice_code']
        if 'invoice_date' in response:
            self.invoice_date = response['invoice_date']
        if 'invoice_img_url' in response:
            self.invoice_img_url = response['invoice_img_url']
        if 'invoice_item_content_list' in response:
            self.invoice_item_content_list = response['invoice_item_content_list']
        if 'invoice_no' in response:
            self.invoice_no = response['invoice_no']
        if 'invoice_status' in response:
            self.invoice_status = response['invoice_status']
        if 'invoice_type' in response:
            self.invoice_type = response['invoice_type']
        if 'payee_address' in response:
            self.payee_address = response['payee_address']
        if 'payee_bank_account' in response:
            self.payee_bank_account = response['payee_bank_account']
        if 'payee_bank_name' in response:
            self.payee_bank_name = response['payee_bank_name']
        if 'payee_phone' in response:
            self.payee_phone = response['payee_phone']
        if 'payee_register_name' in response:
            self.payee_register_name = response['payee_register_name']
        if 'payee_tax_no' in response:
            self.payee_tax_no = response['payee_tax_no']
        if 'payer_address' in response:
            self.payer_address = response['payer_address']
        if 'payer_bank_account' in response:
            self.payer_bank_account = response['payer_bank_account']
        if 'payer_bank_name' in response:
            self.payer_bank_name = response['payer_bank_name']
        if 'payer_name' in response:
            self.payer_name = response['payer_name']
        if 'payer_phone' in response:
            self.payer_phone = response['payer_phone']
        if 'payer_tax_no' in response:
            self.payer_tax_no = response['payer_tax_no']
        if 'sum_tax_amount' in response:
            self.sum_tax_amount = response['sum_tax_amount']
        if 'tax_type' in response:
            self.tax_type = response['tax_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SourceMediaInfo import SourceMediaInfo
from alipay.aop.api.domain.SourceOffer import SourceOffer


class AlipaySocialBaseContentlibStandardcontentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseContentlibStandardcontentQueryResponse, self).__init__()
        self._content_id = None
        self._link = None
        self._source_author = None
        self._source_content = None
        self._source_link = None
        self._source_media_infos = None
        self._source_offers = None
        self._source_publish_date = None
        self._source_status = None
        self._source_summary = None
        self._source_title = None
        self._source_type = None
        self._special_tags = None

    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def source_author(self):
        return self._source_author

    @source_author.setter
    def source_author(self, value):
        self._source_author = value
    @property
    def source_content(self):
        return self._source_content

    @source_content.setter
    def source_content(self, value):
        self._source_content = value
    @property
    def source_link(self):
        return self._source_link

    @source_link.setter
    def source_link(self, value):
        self._source_link = value
    @property
    def source_media_infos(self):
        return self._source_media_infos

    @source_media_infos.setter
    def source_media_infos(self, value):
        if isinstance(value, list):
            self._source_media_infos = list()
            for i in value:
                if isinstance(i, SourceMediaInfo):
                    self._source_media_infos.append(i)
                else:
                    self._source_media_infos.append(SourceMediaInfo.from_alipay_dict(i))
    @property
    def source_offers(self):
        return self._source_offers

    @source_offers.setter
    def source_offers(self, value):
        if isinstance(value, list):
            self._source_offers = list()
            for i in value:
                if isinstance(i, SourceOffer):
                    self._source_offers.append(i)
                else:
                    self._source_offers.append(SourceOffer.from_alipay_dict(i))
    @property
    def source_publish_date(self):
        return self._source_publish_date

    @source_publish_date.setter
    def source_publish_date(self, value):
        self._source_publish_date = value
    @property
    def source_status(self):
        return self._source_status

    @source_status.setter
    def source_status(self, value):
        self._source_status = value
    @property
    def source_summary(self):
        return self._source_summary

    @source_summary.setter
    def source_summary(self, value):
        self._source_summary = value
    @property
    def source_title(self):
        return self._source_title

    @source_title.setter
    def source_title(self, value):
        self._source_title = value
    @property
    def source_type(self):
        return self._source_type

    @source_type.setter
    def source_type(self, value):
        self._source_type = value
    @property
    def special_tags(self):
        return self._special_tags

    @special_tags.setter
    def special_tags(self, value):
        if isinstance(value, list):
            self._special_tags = list()
            for i in value:
                self._special_tags.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseContentlibStandardcontentQueryResponse, self).parse_response_content(response_content)
        if 'content_id' in response:
            self.content_id = response['content_id']
        if 'link' in response:
            self.link = response['link']
        if 'source_author' in response:
            self.source_author = response['source_author']
        if 'source_content' in response:
            self.source_content = response['source_content']
        if 'source_link' in response:
            self.source_link = response['source_link']
        if 'source_media_infos' in response:
            self.source_media_infos = response['source_media_infos']
        if 'source_offers' in response:
            self.source_offers = response['source_offers']
        if 'source_publish_date' in response:
            self.source_publish_date = response['source_publish_date']
        if 'source_status' in response:
            self.source_status = response['source_status']
        if 'source_summary' in response:
            self.source_summary = response['source_summary']
        if 'source_title' in response:
            self.source_title = response['source_title']
        if 'source_type' in response:
            self.source_type = response['source_type']
        if 'special_tags' in response:
            self.special_tags = response['special_tags']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradePeriodDTO(object):

    def __init__(self):
        self._belong_day = None
        self._state_desc = None
        self._trading_day = None

    @property
    def belong_day(self):
        return self._belong_day

    @belong_day.setter
    def belong_day(self, value):
        self._belong_day = value
    @property
    def state_desc(self):
        return self._state_desc

    @state_desc.setter
    def state_desc(self, value):
        self._state_desc = value
    @property
    def trading_day(self):
        return self._trading_day

    @trading_day.setter
    def trading_day(self, value):
        self._trading_day = value


    def to_alipay_dict(self):
        params = dict()
        if self.belong_day:
            if hasattr(self.belong_day, 'to_alipay_dict'):
                params['belong_day'] = self.belong_day.to_alipay_dict()
            else:
                params['belong_day'] = self.belong_day
        if self.state_desc:
            if hasattr(self.state_desc, 'to_alipay_dict'):
                params['state_desc'] = self.state_desc.to_alipay_dict()
            else:
                params['state_desc'] = self.state_desc
        if self.trading_day:
            if hasattr(self.trading_day, 'to_alipay_dict'):
                params['trading_day'] = self.trading_day.to_alipay_dict()
            else:
                params['trading_day'] = self.trading_day
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradePeriodDTO()
        if 'belong_day' in d:
            o.belong_day = d['belong_day']
        if 'state_desc' in d:
            o.state_desc = d['state_desc']
        if 'trading_day' in d:
            o.trading_day = d['trading_day']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicThirdCustomerServiceResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicThirdCustomerServiceResponse, self).__init__()
        self._public_name = None

    @property
    def public_name(self):
        return self._public_name

    @public_name.setter
    def public_name(self, value):
        self._public_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicThirdCustomerServiceResponse, self).parse_response_content(response_content)
        if 'public_name' in response:
            self.public_name = response['public_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserElectronicidUserbarcodeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserElectronicidUserbarcodeCreateResponse, self).__init__()
        self._barcode = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserElectronicidUserbarcodeCreateResponse, self).parse_response_content(response_content)
        if 'barcode' in response:
            self.barcode = response['barcode']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Terminal import Terminal


class AlipayOpenStsTokenGetModel(object):

    def __init__(self):
        self._security_token = None
        self._terminal = None

    @property
    def security_token(self):
        return self._security_token

    @security_token.setter
    def security_token(self, value):
        self._security_token = value
    @property
    def terminal(self):
        return self._terminal

    @terminal.setter
    def terminal(self, value):
        if isinstance(value, Terminal):
            self._terminal = value
        else:
            self._terminal = Terminal.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.security_token:
            if hasattr(self.security_token, 'to_alipay_dict'):
                params['security_token'] = self.security_token.to_alipay_dict()
            else:
                params['security_token'] = self.security_token
        if self.terminal:
            if hasattr(self.terminal, 'to_alipay_dict'):
                params['terminal'] = self.terminal.to_alipay_dict()
            else:
                params['terminal'] = self.terminal
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenStsTokenGetModel()
        if 'security_token' in d:
            o.security_token = d['security_token']
        if 'terminal' in d:
            o.terminal = d['terminal']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotMsgcenterSendModel(object):

    def __init__(self):
        self._content = None
        self._datetime = None
        self._ext_info = None
        self._is_support_link = None
        self._link = None
        self._title = None
        self._type = None
        self._user_id = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def datetime(self):
        return self._datetime

    @datetime.setter
    def datetime(self, value):
        self._datetime = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def is_support_link(self):
        return self._is_support_link

    @is_support_link.setter
    def is_support_link(self, value):
        self._is_support_link = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.datetime:
            if hasattr(self.datetime, 'to_alipay_dict'):
                params['datetime'] = self.datetime.to_alipay_dict()
            else:
                params['datetime'] = self.datetime
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.is_support_link:
            if hasattr(self.is_support_link, 'to_alipay_dict'):
                params['is_support_link'] = self.is_support_link.to_alipay_dict()
            else:
                params['is_support_link'] = self.is_support_link
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMsgcenterSendModel()
        if 'content' in d:
            o.content = d['content']
        if 'datetime' in d:
            o.datetime = d['datetime']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'is_support_link' in d:
            o.is_support_link = d['is_support_link']
        if 'link' in d:
            o.link = d['link']
        if 'title' in d:
            o.title = d['title']
        if 'type' in d:
            o.type = d['type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PortfolioInfoOpenModel(object):

    def __init__(self):
        self._cover_image_id = None
        self._cover_image_type = None
        self._cover_image_url = None
        self._portfolio_id = None
        self._portfolio_title = None

    @property
    def cover_image_id(self):
        return self._cover_image_id

    @cover_image_id.setter
    def cover_image_id(self, value):
        self._cover_image_id = value
    @property
    def cover_image_type(self):
        return self._cover_image_type

    @cover_image_type.setter
    def cover_image_type(self, value):
        self._cover_image_type = value
    @property
    def cover_image_url(self):
        return self._cover_image_url

    @cover_image_url.setter
    def cover_image_url(self, value):
        self._cover_image_url = value
    @property
    def portfolio_id(self):
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, value):
        self._portfolio_id = value
    @property
    def portfolio_title(self):
        return self._portfolio_title

    @portfolio_title.setter
    def portfolio_title(self, value):
        self._portfolio_title = value


    def to_alipay_dict(self):
        params = dict()
        if self.cover_image_id:
            if hasattr(self.cover_image_id, 'to_alipay_dict'):
                params['cover_image_id'] = self.cover_image_id.to_alipay_dict()
            else:
                params['cover_image_id'] = self.cover_image_id
        if self.cover_image_type:
            if hasattr(self.cover_image_type, 'to_alipay_dict'):
                params['cover_image_type'] = self.cover_image_type.to_alipay_dict()
            else:
                params['cover_image_type'] = self.cover_image_type
        if self.cover_image_url:
            if hasattr(self.cover_image_url, 'to_alipay_dict'):
                params['cover_image_url'] = self.cover_image_url.to_alipay_dict()
            else:
                params['cover_image_url'] = self.cover_image_url
        if self.portfolio_id:
            if hasattr(self.portfolio_id, 'to_alipay_dict'):
                params['portfolio_id'] = self.portfolio_id.to_alipay_dict()
            else:
                params['portfolio_id'] = self.portfolio_id
        if self.portfolio_title:
            if hasattr(self.portfolio_title, 'to_alipay_dict'):
                params['portfolio_title'] = self.portfolio_title.to_alipay_dict()
            else:
                params['portfolio_title'] = self.portfolio_title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PortfolioInfoOpenModel()
        if 'cover_image_id' in d:
            o.cover_image_id = d['cover_image_id']
        if 'cover_image_type' in d:
            o.cover_image_type = d['cover_image_type']
        if 'cover_image_url' in d:
            o.cover_image_url = d['cover_image_url']
        if 'portfolio_id' in d:
            o.portfolio_id = d['portfolio_id']
        if 'portfolio_title' in d:
            o.portfolio_title = d['portfolio_title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundFlexiblestaffingAuthorizeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundFlexiblestaffingAuthorizeQueryResponse, self).__init__()
        self._authorize_time = None
        self._authorized_party_name = None
        self._biz_scene = None
        self._out_biz_no = None
        self._principal_id = None
        self._product_code = None
        self._status = None

    @property
    def authorize_time(self):
        return self._authorize_time

    @authorize_time.setter
    def authorize_time(self, value):
        self._authorize_time = value
    @property
    def authorized_party_name(self):
        return self._authorized_party_name

    @authorized_party_name.setter
    def authorized_party_name(self, value):
        self._authorized_party_name = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundFlexiblestaffingAuthorizeQueryResponse, self).parse_response_content(response_content)
        if 'authorize_time' in response:
            self.authorize_time = response['authorize_time']
        if 'authorized_party_name' in response:
            self.authorized_party_name = response['authorized_party_name']
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'principal_id' in response:
            self.principal_id = response['principal_id']
        if 'product_code' in response:
            self.product_code = response['product_code']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.Voucher import Voucher


class KoubeiMarketingCampaignVoucherDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignVoucherDetailQueryResponse, self).__init__()
        self._status = None
        self._voucher = None
        self._voucher_id = None

    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def voucher(self):
        return self._voucher

    @voucher.setter
    def voucher(self, value):
        if isinstance(value, Voucher):
            self._voucher = value
        else:
            self._voucher = Voucher.from_alipay_dict(value)
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignVoucherDetailQueryResponse, self).parse_response_content(response_content)
        if 'status' in response:
            self.status = response['status']
        if 'voucher' in response:
            self.voucher = response['voucher']
        if 'voucher_id' in response:
            self.voucher_id = response['voucher_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignTaskResult(object):

    def __init__(self):
        self._biz_id = None
        self._sign_enter_url = None
        self._task_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def sign_enter_url(self):
        return self._sign_enter_url

    @sign_enter_url.setter
    def sign_enter_url(self, value):
        self._sign_enter_url = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.sign_enter_url:
            if hasattr(self.sign_enter_url, 'to_alipay_dict'):
                params['sign_enter_url'] = self.sign_enter_url.to_alipay_dict()
            else:
                params['sign_enter_url'] = self.sign_enter_url
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignTaskResult()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'sign_enter_url' in d:
            o.sign_enter_url = d['sign_enter_url']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditEpScoreGetResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpScoreGetResponse, self).__init__()
        self._biz_no = None
        self._eval_date = None
        self._reason = None
        self._zm_score = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def eval_date(self):
        return self._eval_date

    @eval_date.setter
    def eval_date(self, value):
        self._eval_date = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def zm_score(self):
        return self._zm_score

    @zm_score.setter
    def zm_score(self, value):
        self._zm_score = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpScoreGetResponse, self).parse_response_content(response_content)
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'eval_date' in response:
            self.eval_date = response['eval_date']
        if 'reason' in response:
            self.reason = response['reason']
        if 'zm_score' in response:
            self.zm_score = response['zm_score']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerCertificationQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerCertificationQueryResponse, self).__init__()
        self._attribute_info = None
        self._channel_statuses = None
        self._failed_reason = None
        self._identity_info = None
        self._passed = None

    @property
    def attribute_info(self):
        return self._attribute_info

    @attribute_info.setter
    def attribute_info(self, value):
        self._attribute_info = value
    @property
    def channel_statuses(self):
        return self._channel_statuses

    @channel_statuses.setter
    def channel_statuses(self, value):
        self._channel_statuses = value
    @property
    def failed_reason(self):
        return self._failed_reason

    @failed_reason.setter
    def failed_reason(self, value):
        self._failed_reason = value
    @property
    def identity_info(self):
        return self._identity_info

    @identity_info.setter
    def identity_info(self, value):
        self._identity_info = value
    @property
    def passed(self):
        return self._passed

    @passed.setter
    def passed(self, value):
        self._passed = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerCertificationQueryResponse, self).parse_response_content(response_content)
        if 'attribute_info' in response:
            self.attribute_info = response['attribute_info']
        if 'channel_statuses' in response:
            self.channel_statuses = response['channel_statuses']
        if 'failed_reason' in response:
            self.failed_reason = response['failed_reason']
        if 'identity_info' in response:
            self.identity_info = response['identity_info']
        if 'passed' in response:
            self.passed = response['passed']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCliveFeedbackSubmitModel(object):

    def __init__(self):
        self._conversation_id = None
        self._feedback_note = None
        self._score = None
        self._visitor_id = None

    @property
    def conversation_id(self):
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, value):
        self._conversation_id = value
    @property
    def feedback_note(self):
        return self._feedback_note

    @feedback_note.setter
    def feedback_note(self, value):
        self._feedback_note = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def visitor_id(self):
        return self._visitor_id

    @visitor_id.setter
    def visitor_id(self, value):
        self._visitor_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.conversation_id:
            if hasattr(self.conversation_id, 'to_alipay_dict'):
                params['conversation_id'] = self.conversation_id.to_alipay_dict()
            else:
                params['conversation_id'] = self.conversation_id
        if self.feedback_note:
            if hasattr(self.feedback_note, 'to_alipay_dict'):
                params['feedback_note'] = self.feedback_note.to_alipay_dict()
            else:
                params['feedback_note'] = self.feedback_note
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        if self.visitor_id:
            if hasattr(self.visitor_id, 'to_alipay_dict'):
                params['visitor_id'] = self.visitor_id.to_alipay_dict()
            else:
                params['visitor_id'] = self.visitor_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCliveFeedbackSubmitModel()
        if 'conversation_id' in d:
            o.conversation_id = d['conversation_id']
        if 'feedback_note' in d:
            o.feedback_note = d['feedback_note']
        if 'score' in d:
            o.score = d['score']
        if 'visitor_id' in d:
            o.visitor_id = d['visitor_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FengdieActivityPage import FengdieActivityPage


class FengdieActivity(object):

    def __init__(self):
        self._id = None
        self._is_online = None
        self._name = None
        self._nick_name = None
        self._offline_time = None
        self._page = None
        self._publish_time = None
        self._status = None
        self._template_id = None
        self._title = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def is_online(self):
        return self._is_online

    @is_online.setter
    def is_online(self, value):
        self._is_online = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def nick_name(self):
        return self._nick_name

    @nick_name.setter
    def nick_name(self, value):
        self._nick_name = value
    @property
    def offline_time(self):
        return self._offline_time

    @offline_time.setter
    def offline_time(self, value):
        self._offline_time = value
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        if isinstance(value, list):
            self._page = list()
            for i in value:
                if isinstance(i, FengdieActivityPage):
                    self._page.append(i)
                else:
                    self._page.append(FengdieActivityPage.from_alipay_dict(i))
    @property
    def publish_time(self):
        return self._publish_time

    @publish_time.setter
    def publish_time(self, value):
        self._publish_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.is_online:
            if hasattr(self.is_online, 'to_alipay_dict'):
                params['is_online'] = self.is_online.to_alipay_dict()
            else:
                params['is_online'] = self.is_online
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.nick_name:
            if hasattr(self.nick_name, 'to_alipay_dict'):
                params['nick_name'] = self.nick_name.to_alipay_dict()
            else:
                params['nick_name'] = self.nick_name
        if self.offline_time:
            if hasattr(self.offline_time, 'to_alipay_dict'):
                params['offline_time'] = self.offline_time.to_alipay_dict()
            else:
                params['offline_time'] = self.offline_time
        if self.page:
            if isinstance(self.page, list):
                for i in range(0, len(self.page)):
                    element = self.page[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.page[i] = element.to_alipay_dict()
            if hasattr(self.page, 'to_alipay_dict'):
                params['page'] = self.page.to_alipay_dict()
            else:
                params['page'] = self.page
        if self.publish_time:
            if hasattr(self.publish_time, 'to_alipay_dict'):
                params['publish_time'] = self.publish_time.to_alipay_dict()
            else:
                params['publish_time'] = self.publish_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieActivity()
        if 'id' in d:
            o.id = d['id']
        if 'is_online' in d:
            o.is_online = d['is_online']
        if 'name' in d:
            o.name = d['name']
        if 'nick_name' in d:
            o.nick_name = d['nick_name']
        if 'offline_time' in d:
            o.offline_time = d['offline_time']
        if 'page' in d:
            o.page = d['page']
        if 'publish_time' in d:
            o.publish_time = d['publish_time']
        if 'status' in d:
            o.status = d['status']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotVspOrgUserAddUserInfoRequest import IotVspOrgUserAddUserInfoRequest


class AlipayOpenIotvspUserCreateModel(object):

    def __init__(self):
        self._component_out_id = None
        self._isv_pid = None
        self._org_out_id = None
        self._user_info_list = None

    @property
    def component_out_id(self):
        return self._component_out_id

    @component_out_id.setter
    def component_out_id(self, value):
        self._component_out_id = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def org_out_id(self):
        return self._org_out_id

    @org_out_id.setter
    def org_out_id(self, value):
        self._org_out_id = value
    @property
    def user_info_list(self):
        return self._user_info_list

    @user_info_list.setter
    def user_info_list(self, value):
        if isinstance(value, list):
            self._user_info_list = list()
            for i in value:
                if isinstance(i, IotVspOrgUserAddUserInfoRequest):
                    self._user_info_list.append(i)
                else:
                    self._user_info_list.append(IotVspOrgUserAddUserInfoRequest.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.component_out_id:
            if hasattr(self.component_out_id, 'to_alipay_dict'):
                params['component_out_id'] = self.component_out_id.to_alipay_dict()
            else:
                params['component_out_id'] = self.component_out_id
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.org_out_id:
            if hasattr(self.org_out_id, 'to_alipay_dict'):
                params['org_out_id'] = self.org_out_id.to_alipay_dict()
            else:
                params['org_out_id'] = self.org_out_id
        if self.user_info_list:
            if isinstance(self.user_info_list, list):
                for i in range(0, len(self.user_info_list)):
                    element = self.user_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_info_list[i] = element.to_alipay_dict()
            if hasattr(self.user_info_list, 'to_alipay_dict'):
                params['user_info_list'] = self.user_info_list.to_alipay_dict()
            else:
                params['user_info_list'] = self.user_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotvspUserCreateModel()
        if 'component_out_id' in d:
            o.component_out_id = d['component_out_id']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'org_out_id' in d:
            o.org_out_id = d['org_out_id']
        if 'user_info_list' in d:
            o.user_info_list = d['user_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiSalesLeadsShopleadsCreateModel(object):

    def __init__(self):
        self._address = None
        self._branch_name = None
        self._brand_id = None
        self._category_id = None
        self._city_id = None
        self._company_name = None
        self._contacts_name = None
        self._contacts_no = None
        self._country_id = None
        self._district_id = None
        self._ext_info = None
        self._head_shop_name = None
        self._latitude = None
        self._longitude = None
        self._memo = None
        self._province_id = None
        self._register_date = None
        self._request_id = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def branch_name(self):
        return self._branch_name

    @branch_name.setter
    def branch_name(self, value):
        self._branch_name = value
    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def city_id(self):
        return self._city_id

    @city_id.setter
    def city_id(self, value):
        self._city_id = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def contacts_name(self):
        return self._contacts_name

    @contacts_name.setter
    def contacts_name(self, value):
        self._contacts_name = value
    @property
    def contacts_no(self):
        return self._contacts_no

    @contacts_no.setter
    def contacts_no(self, value):
        self._contacts_no = value
    @property
    def country_id(self):
        return self._country_id

    @country_id.setter
    def country_id(self, value):
        self._country_id = value
    @property
    def district_id(self):
        return self._district_id

    @district_id.setter
    def district_id(self, value):
        self._district_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def head_shop_name(self):
        return self._head_shop_name

    @head_shop_name.setter
    def head_shop_name(self, value):
        self._head_shop_name = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def province_id(self):
        return self._province_id

    @province_id.setter
    def province_id(self, value):
        self._province_id = value
    @property
    def register_date(self):
        return self._register_date

    @register_date.setter
    def register_date(self, value):
        self._register_date = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.branch_name:
            if hasattr(self.branch_name, 'to_alipay_dict'):
                params['branch_name'] = self.branch_name.to_alipay_dict()
            else:
                params['branch_name'] = self.branch_name
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.city_id:
            if hasattr(self.city_id, 'to_alipay_dict'):
                params['city_id'] = self.city_id.to_alipay_dict()
            else:
                params['city_id'] = self.city_id
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.contacts_name:
            if hasattr(self.contacts_name, 'to_alipay_dict'):
                params['contacts_name'] = self.contacts_name.to_alipay_dict()
            else:
                params['contacts_name'] = self.contacts_name
        if self.contacts_no:
            if hasattr(self.contacts_no, 'to_alipay_dict'):
                params['contacts_no'] = self.contacts_no.to_alipay_dict()
            else:
                params['contacts_no'] = self.contacts_no
        if self.country_id:
            if hasattr(self.country_id, 'to_alipay_dict'):
                params['country_id'] = self.country_id.to_alipay_dict()
            else:
                params['country_id'] = self.country_id
        if self.district_id:
            if hasattr(self.district_id, 'to_alipay_dict'):
                params['district_id'] = self.district_id.to_alipay_dict()
            else:
                params['district_id'] = self.district_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.head_shop_name:
            if hasattr(self.head_shop_name, 'to_alipay_dict'):
                params['head_shop_name'] = self.head_shop_name.to_alipay_dict()
            else:
                params['head_shop_name'] = self.head_shop_name
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.province_id:
            if hasattr(self.province_id, 'to_alipay_dict'):
                params['province_id'] = self.province_id.to_alipay_dict()
            else:
                params['province_id'] = self.province_id
        if self.register_date:
            if hasattr(self.register_date, 'to_alipay_dict'):
                params['register_date'] = self.register_date.to_alipay_dict()
            else:
                params['register_date'] = self.register_date
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiSalesLeadsShopleadsCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'branch_name' in d:
            o.branch_name = d['branch_name']
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'city_id' in d:
            o.city_id = d['city_id']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'contacts_name' in d:
            o.contacts_name = d['contacts_name']
        if 'contacts_no' in d:
            o.contacts_no = d['contacts_no']
        if 'country_id' in d:
            o.country_id = d['country_id']
        if 'district_id' in d:
            o.district_id = d['district_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'head_shop_name' in d:
            o.head_shop_name = d['head_shop_name']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'memo' in d:
            o.memo = d['memo']
        if 'province_id' in d:
            o.province_id = d['province_id']
        if 'register_date' in d:
            o.register_date = d['register_date']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PlatformPetProfile import PlatformPetProfile


class AlipayInsScenePetprofilePlatformprofileMatchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsScenePetprofilePlatformprofileMatchResponse, self).__init__()
        self._pet_profiles = None

    @property
    def pet_profiles(self):
        return self._pet_profiles

    @pet_profiles.setter
    def pet_profiles(self, value):
        if isinstance(value, list):
            self._pet_profiles = list()
            for i in value:
                if isinstance(i, PlatformPetProfile):
                    self._pet_profiles.append(i)
                else:
                    self._pet_profiles.append(PlatformPetProfile.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayInsScenePetprofilePlatformprofileMatchResponse, self).parse_response_content(response_content)
        if 'pet_profiles' in response:
            self.pet_profiles = response['pet_profiles']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossBaseProcessTaskUpdatecontextModel(object):

    def __init__(self):
        self._context = None
        self._priority = None
        self._puid = None
        self._sub_contexts = None

    @property
    def context(self):
        return self._context

    @context.setter
    def context(self, value):
        self._context = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        self._puid = value
    @property
    def sub_contexts(self):
        return self._sub_contexts

    @sub_contexts.setter
    def sub_contexts(self, value):
        if isinstance(value, list):
            self._sub_contexts = list()
            for i in value:
                self._sub_contexts.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.context:
            if hasattr(self.context, 'to_alipay_dict'):
                params['context'] = self.context.to_alipay_dict()
            else:
                params['context'] = self.context
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        if self.sub_contexts:
            if isinstance(self.sub_contexts, list):
                for i in range(0, len(self.sub_contexts)):
                    element = self.sub_contexts[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_contexts[i] = element.to_alipay_dict()
            if hasattr(self.sub_contexts, 'to_alipay_dict'):
                params['sub_contexts'] = self.sub_contexts.to_alipay_dict()
            else:
                params['sub_contexts'] = self.sub_contexts
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossBaseProcessTaskUpdatecontextModel()
        if 'context' in d:
            o.context = d['context']
        if 'priority' in d:
            o.priority = d['priority']
        if 'puid' in d:
            o.puid = d['puid']
        if 'sub_contexts' in d:
            o.sub_contexts = d['sub_contexts']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceTitleDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceTitleDetailQueryResponse, self).__init__()
        self._address = None
        self._name = None
        self._open_bank_account = None
        self._open_bank_name = None
        self._tax_register_no = None
        self._telephone = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_bank_account(self):
        return self._open_bank_account

    @open_bank_account.setter
    def open_bank_account(self, value):
        self._open_bank_account = value
    @property
    def open_bank_name(self):
        return self._open_bank_name

    @open_bank_name.setter
    def open_bank_name(self, value):
        self._open_bank_name = value
    @property
    def tax_register_no(self):
        return self._tax_register_no

    @tax_register_no.setter
    def tax_register_no(self, value):
        self._tax_register_no = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceTitleDetailQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'name' in response:
            self.name = response['name']
        if 'open_bank_account' in response:
            self.open_bank_account = response['open_bank_account']
        if 'open_bank_name' in response:
            self.open_bank_name = response['open_bank_name']
        if 'tax_register_no' in response:
            self.tax_register_no = response['tax_register_no']
        if 'telephone' in response:
            self.telephone = response['telephone']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskAntifraudBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskAntifraudBatchqueryResponse, self).__init__()
        self._company_relation_list = None
        self._staff_company_relation_list = None

    @property
    def company_relation_list(self):
        return self._company_relation_list

    @company_relation_list.setter
    def company_relation_list(self, value):
        if isinstance(value, list):
            self._company_relation_list = list()
            for i in value:
                self._company_relation_list.append(i)
    @property
    def staff_company_relation_list(self):
        return self._staff_company_relation_list

    @staff_company_relation_list.setter
    def staff_company_relation_list(self, value):
        if isinstance(value, list):
            self._staff_company_relation_list = list()
            for i in value:
                self._staff_company_relation_list.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskAntifraudBatchqueryResponse, self).parse_response_content(response_content)
        if 'company_relation_list' in response:
            self.company_relation_list = response['company_relation_list']
        if 'staff_company_relation_list' in response:
            self.staff_company_relation_list = response['staff_company_relation_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EntertainmentOrderInfo import EntertainmentOrderInfo


class AlipayEcoEntertainmentOrderUploadModel(object):

    def __init__(self):
        self._entertainment_order_info = None

    @property
    def entertainment_order_info(self):
        return self._entertainment_order_info

    @entertainment_order_info.setter
    def entertainment_order_info(self, value):
        if isinstance(value, EntertainmentOrderInfo):
            self._entertainment_order_info = value
        else:
            self._entertainment_order_info = EntertainmentOrderInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.entertainment_order_info:
            if hasattr(self.entertainment_order_info, 'to_alipay_dict'):
                params['entertainment_order_info'] = self.entertainment_order_info.to_alipay_dict()
            else:
                params['entertainment_order_info'] = self.entertainment_order_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEntertainmentOrderUploadModel()
        if 'entertainment_order_info' in d:
            o.entertainment_order_info = d['entertainment_order_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AttachmentDetail import AttachmentDetail
from alipay.aop.api.domain.DocInfo import DocInfo


class AlipayEcoSignflowsDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoSignflowsDetailQueryResponse, self).__init__()
        self._attachments = None
        self._docs = None

    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, AttachmentDetail):
            self._attachments = value
        else:
            self._attachments = AttachmentDetail.from_alipay_dict(value)
    @property
    def docs(self):
        return self._docs

    @docs.setter
    def docs(self, value):
        if isinstance(value, DocInfo):
            self._docs = value
        else:
            self._docs = DocInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayEcoSignflowsDetailQueryResponse, self).parse_response_content(response_content)
        if 'attachments' in response:
            self.attachments = response['attachments']
        if 'docs' in response:
            self.docs = response['docs']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.EtcMediaContent import EtcMediaContent


class AlipayCommerceTransportEtcResouceGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportEtcResouceGetResponse, self).__init__()
        self._biz_code = None
        self._biz_msg = None
        self._content_list = None
        self._order_id = None
        self._out_biz_no = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_msg(self):
        return self._biz_msg

    @biz_msg.setter
    def biz_msg(self, value):
        self._biz_msg = value
    @property
    def content_list(self):
        return self._content_list

    @content_list.setter
    def content_list(self, value):
        if isinstance(value, list):
            self._content_list = list()
            for i in value:
                if isinstance(i, EtcMediaContent):
                    self._content_list.append(i)
                else:
                    self._content_list.append(EtcMediaContent.from_alipay_dict(i))
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportEtcResouceGetResponse, self).parse_response_content(response_content)
        if 'biz_code' in response:
            self.biz_code = response['biz_code']
        if 'biz_msg' in response:
            self.biz_msg = response['biz_msg']
        if 'content_list' in response:
            self.content_list = response['content_list']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpFreedepositInitializeModel(object):

    def __init__(self):
        self._biz_channel = None
        self._biz_source = None
        self._cert_no = None
        self._cert_type = None
        self._credit_category = None
        self._ep_cert_no = None
        self._ep_cert_type = None
        self._ep_name = None
        self._goto_url = None
        self._member_type = None
        self._merchant_order_no = None
        self._name = None
        self._out_request_no = None
        self._product_code = None
        self._request_id = None

    @property
    def biz_channel(self):
        return self._biz_channel

    @biz_channel.setter
    def biz_channel(self, value):
        self._biz_channel = value
    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def credit_category(self):
        return self._credit_category

    @credit_category.setter
    def credit_category(self, value):
        self._credit_category = value
    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_cert_type(self):
        return self._ep_cert_type

    @ep_cert_type.setter
    def ep_cert_type(self, value):
        self._ep_cert_type = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def goto_url(self):
        return self._goto_url

    @goto_url.setter
    def goto_url(self, value):
        self._goto_url = value
    @property
    def member_type(self):
        return self._member_type

    @member_type.setter
    def member_type(self, value):
        self._member_type = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_channel:
            if hasattr(self.biz_channel, 'to_alipay_dict'):
                params['biz_channel'] = self.biz_channel.to_alipay_dict()
            else:
                params['biz_channel'] = self.biz_channel
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.credit_category:
            if hasattr(self.credit_category, 'to_alipay_dict'):
                params['credit_category'] = self.credit_category.to_alipay_dict()
            else:
                params['credit_category'] = self.credit_category
        if self.ep_cert_no:
            if hasattr(self.ep_cert_no, 'to_alipay_dict'):
                params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
            else:
                params['ep_cert_no'] = self.ep_cert_no
        if self.ep_cert_type:
            if hasattr(self.ep_cert_type, 'to_alipay_dict'):
                params['ep_cert_type'] = self.ep_cert_type.to_alipay_dict()
            else:
                params['ep_cert_type'] = self.ep_cert_type
        if self.ep_name:
            if hasattr(self.ep_name, 'to_alipay_dict'):
                params['ep_name'] = self.ep_name.to_alipay_dict()
            else:
                params['ep_name'] = self.ep_name
        if self.goto_url:
            if hasattr(self.goto_url, 'to_alipay_dict'):
                params['goto_url'] = self.goto_url.to_alipay_dict()
            else:
                params['goto_url'] = self.goto_url
        if self.member_type:
            if hasattr(self.member_type, 'to_alipay_dict'):
                params['member_type'] = self.member_type.to_alipay_dict()
            else:
                params['member_type'] = self.member_type
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpFreedepositInitializeModel()
        if 'biz_channel' in d:
            o.biz_channel = d['biz_channel']
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'credit_category' in d:
            o.credit_category = d['credit_category']
        if 'ep_cert_no' in d:
            o.ep_cert_no = d['ep_cert_no']
        if 'ep_cert_type' in d:
            o.ep_cert_type = d['ep_cert_type']
        if 'ep_name' in d:
            o.ep_name = d['ep_name']
        if 'goto_url' in d:
            o.goto_url = d['goto_url']
        if 'member_type' in d:
            o.member_type = d['member_type']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'name' in d:
            o.name = d['name']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainCreditpaySellerunsignQueryModel(object):

    def __init__(self):
        self._ar_no = None
        self._channel_tag = None
        self._request_id = None
        self._seller = None
        self._seller_scene_id = None
        self._shop_id = None
        self._trace_id = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def channel_tag(self):
        return self._channel_tag

    @channel_tag.setter
    def channel_tag(self, value):
        self._channel_tag = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, Member):
            self._seller = value
        else:
            self._seller = Member.from_alipay_dict(value)
    @property
    def seller_scene_id(self):
        return self._seller_scene_id

    @seller_scene_id.setter
    def seller_scene_id(self, value):
        self._seller_scene_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.channel_tag:
            if hasattr(self.channel_tag, 'to_alipay_dict'):
                params['channel_tag'] = self.channel_tag.to_alipay_dict()
            else:
                params['channel_tag'] = self.channel_tag
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.seller_scene_id:
            if hasattr(self.seller_scene_id, 'to_alipay_dict'):
                params['seller_scene_id'] = self.seller_scene_id.to_alipay_dict()
            else:
                params['seller_scene_id'] = self.seller_scene_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainCreditpaySellerunsignQueryModel()
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'channel_tag' in d:
            o.channel_tag = d['channel_tag']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'seller' in d:
            o.seller = d['seller']
        if 'seller_scene_id' in d:
            o.seller_scene_id = d['seller_scene_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HbMeiWeishopInfo(object):

    def __init__(self):
        self._city_code = None
        self._city_name = None
        self._logo = None
        self._pirce_per_avg_shop = None
        self._poi_name = None
        self._province_code = None
        self._province_name = None
        self._shop_gis = None
        self._shop_id = None
        self._shop_name = None
        self._star_rate_shop = None
        self._status = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def pirce_per_avg_shop(self):
        return self._pirce_per_avg_shop

    @pirce_per_avg_shop.setter
    def pirce_per_avg_shop(self, value):
        self._pirce_per_avg_shop = value
    @property
    def poi_name(self):
        return self._poi_name

    @poi_name.setter
    def poi_name(self, value):
        self._poi_name = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def shop_gis(self):
        return self._shop_gis

    @shop_gis.setter
    def shop_gis(self, value):
        self._shop_gis = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def star_rate_shop(self):
        return self._star_rate_shop

    @star_rate_shop.setter
    def star_rate_shop(self, value):
        self._star_rate_shop = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.pirce_per_avg_shop:
            if hasattr(self.pirce_per_avg_shop, 'to_alipay_dict'):
                params['pirce_per_avg_shop'] = self.pirce_per_avg_shop.to_alipay_dict()
            else:
                params['pirce_per_avg_shop'] = self.pirce_per_avg_shop
        if self.poi_name:
            if hasattr(self.poi_name, 'to_alipay_dict'):
                params['poi_name'] = self.poi_name.to_alipay_dict()
            else:
                params['poi_name'] = self.poi_name
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.shop_gis:
            if hasattr(self.shop_gis, 'to_alipay_dict'):
                params['shop_gis'] = self.shop_gis.to_alipay_dict()
            else:
                params['shop_gis'] = self.shop_gis
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.star_rate_shop:
            if hasattr(self.star_rate_shop, 'to_alipay_dict'):
                params['star_rate_shop'] = self.star_rate_shop.to_alipay_dict()
            else:
                params['star_rate_shop'] = self.star_rate_shop
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HbMeiWeishopInfo()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'logo' in d:
            o.logo = d['logo']
        if 'pirce_per_avg_shop' in d:
            o.pirce_per_avg_shop = d['pirce_per_avg_shop']
        if 'poi_name' in d:
            o.poi_name = d['poi_name']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'shop_gis' in d:
            o.shop_gis = d['shop_gis']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'star_rate_shop' in d:
            o.star_rate_shop = d['star_rate_shop']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NewsfeedMediaLinkInfo(object):

    def __init__(self):
        self._content_id = None
        self._content_source = None
        self._content_type = None
        self._desc = None
        self._thumb = None
        self._title = None
        self._url = None

    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def content_source(self):
        return self._content_source

    @content_source.setter
    def content_source(self, value):
        self._content_source = value
    @property
    def content_type(self):
        return self._content_type

    @content_type.setter
    def content_type(self, value):
        self._content_type = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def thumb(self):
        return self._thumb

    @thumb.setter
    def thumb(self, value):
        self._thumb = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.content_source:
            if hasattr(self.content_source, 'to_alipay_dict'):
                params['content_source'] = self.content_source.to_alipay_dict()
            else:
                params['content_source'] = self.content_source
        if self.content_type:
            if hasattr(self.content_type, 'to_alipay_dict'):
                params['content_type'] = self.content_type.to_alipay_dict()
            else:
                params['content_type'] = self.content_type
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.thumb:
            if hasattr(self.thumb, 'to_alipay_dict'):
                params['thumb'] = self.thumb.to_alipay_dict()
            else:
                params['thumb'] = self.thumb
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NewsfeedMediaLinkInfo()
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'content_source' in d:
            o.content_source = d['content_source']
        if 'content_type' in d:
            o.content_type = d['content_type']
        if 'desc' in d:
            o.desc = d['desc']
        if 'thumb' in d:
            o.thumb = d['thumb']
        if 'title' in d:
            o.title = d['title']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayBusinessItemTicketSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBusinessItemTicketSyncResponse, self).__init__()
        self._object_id = None
        self._status = None

    @property
    def object_id(self):
        return self._object_id

    @object_id.setter
    def object_id(self, value):
        self._object_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayBusinessItemTicketSyncResponse, self).parse_response_content(response_content)
        if 'object_id' in response:
            self.object_id = response['object_id']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMsaasMediarecogMmtcaftscvTemplateVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMsaasMediarecogMmtcaftscvTemplateVerifyResponse, self).__init__()
        self._accuracy = None
        self._pass = None
        self._remark = None

    @property
    def accuracy(self):
        return self._accuracy

    @accuracy.setter
    def accuracy(self, value):
        self._accuracy = value
    @property
    def pass(self):
        return self._pass

    @pass.setter
    def pass(self, value):
        self._pass = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value

    def parse_response_content(self, response_content):
        response = super(AlipayMsaasMediarecogMmtcaftscvTemplateVerifyResponse, self).parse_response_content(response_content)
        if 'accuracy' in response:
            self.accuracy = response['accuracy']
        if 'pass' in response:
            self.pass = response['pass']
        if 'remark' in response:
            self.remark = response['remark']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntOcrIdcardIdentifyModel(object):

    def __init__(self):
        self._image = None
        self._side = None
        self._type = None

    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def side(self):
        return self._side

    @side.setter
    def side(self, value):
        self._side = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.side:
            if hasattr(self.side, 'to_alipay_dict'):
                params['side'] = self.side.to_alipay_dict()
            else:
                params['side'] = self.side
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntOcrIdcardIdentifyModel()
        if 'image' in d:
            o.image = d['image']
        if 'side' in d:
            o.side = d['side']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LegalRepresentativeVO import LegalRepresentativeVO
from alipay.aop.api.domain.ManagerVO import ManagerVO
from alipay.aop.api.domain.StockHolderVO import StockHolderVO
from alipay.aop.api.domain.UboVO import UboVO


class VerifyInfoVO(object):

    def __init__(self):
        self._business_address = None
        self._company_name = None
        self._ever_org_name = None
        self._industry_name = None
        self._legal_representative = None
        self._local_tax_no = None
        self._logoff_date = None
        self._managers = None
        self._norm_opr_project = None
        self._opr_status = None
        self._oprt_end_date = None
        self._oprt_start_date = None
        self._org_actual_cptl = None
        self._org_reg_addr = None
        self._org_reg_cptl = None
        self._org_reg_cptl_curcy = None
        self._org_reg_opr_scope = None
        self._org_type = None
        self._org_website = None
        self._permit_opr_project = None
        self._registration_country = None
        self._registration_date = None
        self._registration_no = None
        self._revoke_date = None
        self._stock_holders = None
        self._ubos = None
        self._uc_code = None

    @property
    def business_address(self):
        return self._business_address

    @business_address.setter
    def business_address(self, value):
        self._business_address = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def ever_org_name(self):
        return self._ever_org_name

    @ever_org_name.setter
    def ever_org_name(self, value):
        self._ever_org_name = value
    @property
    def industry_name(self):
        return self._industry_name

    @industry_name.setter
    def industry_name(self, value):
        self._industry_name = value
    @property
    def legal_representative(self):
        return self._legal_representative

    @legal_representative.setter
    def legal_representative(self, value):
        if isinstance(value, LegalRepresentativeVO):
            self._legal_representative = value
        else:
            self._legal_representative = LegalRepresentativeVO.from_alipay_dict(value)
    @property
    def local_tax_no(self):
        return self._local_tax_no

    @local_tax_no.setter
    def local_tax_no(self, value):
        self._local_tax_no = value
    @property
    def logoff_date(self):
        return self._logoff_date

    @logoff_date.setter
    def logoff_date(self, value):
        self._logoff_date = value
    @property
    def managers(self):
        return self._managers

    @managers.setter
    def managers(self, value):
        if isinstance(value, list):
            self._managers = list()
            for i in value:
                if isinstance(i, ManagerVO):
                    self._managers.append(i)
                else:
                    self._managers.append(ManagerVO.from_alipay_dict(i))
    @property
    def norm_opr_project(self):
        return self._norm_opr_project

    @norm_opr_project.setter
    def norm_opr_project(self, value):
        self._norm_opr_project = value
    @property
    def opr_status(self):
        return self._opr_status

    @opr_status.setter
    def opr_status(self, value):
        self._opr_status = value
    @property
    def oprt_end_date(self):
        return self._oprt_end_date

    @oprt_end_date.setter
    def oprt_end_date(self, value):
        self._oprt_end_date = value
    @property
    def oprt_start_date(self):
        return self._oprt_start_date

    @oprt_start_date.setter
    def oprt_start_date(self, value):
        self._oprt_start_date = value
    @property
    def org_actual_cptl(self):
        return self._org_actual_cptl

    @org_actual_cptl.setter
    def org_actual_cptl(self, value):
        self._org_actual_cptl = value
    @property
    def org_reg_addr(self):
        return self._org_reg_addr

    @org_reg_addr.setter
    def org_reg_addr(self, value):
        self._org_reg_addr = value
    @property
    def org_reg_cptl(self):
        return self._org_reg_cptl

    @org_reg_cptl.setter
    def org_reg_cptl(self, value):
        self._org_reg_cptl = value
    @property
    def org_reg_cptl_curcy(self):
        return self._org_reg_cptl_curcy

    @org_reg_cptl_curcy.setter
    def org_reg_cptl_curcy(self, value):
        self._org_reg_cptl_curcy = value
    @property
    def org_reg_opr_scope(self):
        return self._org_reg_opr_scope

    @org_reg_opr_scope.setter
    def org_reg_opr_scope(self, value):
        self._org_reg_opr_scope = value
    @property
    def org_type(self):
        return self._org_type

    @org_type.setter
    def org_type(self, value):
        self._org_type = value
    @property
    def org_website(self):
        return self._org_website

    @org_website.setter
    def org_website(self, value):
        self._org_website = value
    @property
    def permit_opr_project(self):
        return self._permit_opr_project

    @permit_opr_project.setter
    def permit_opr_project(self, value):
        self._permit_opr_project = value
    @property
    def registration_country(self):
        return self._registration_country

    @registration_country.setter
    def registration_country(self, value):
        self._registration_country = value
    @property
    def registration_date(self):
        return self._registration_date

    @registration_date.setter
    def registration_date(self, value):
        self._registration_date = value
    @property
    def registration_no(self):
        return self._registration_no

    @registration_no.setter
    def registration_no(self, value):
        self._registration_no = value
    @property
    def revoke_date(self):
        return self._revoke_date

    @revoke_date.setter
    def revoke_date(self, value):
        self._revoke_date = value
    @property
    def stock_holders(self):
        return self._stock_holders

    @stock_holders.setter
    def stock_holders(self, value):
        if isinstance(value, list):
            self._stock_holders = list()
            for i in value:
                if isinstance(i, StockHolderVO):
                    self._stock_holders.append(i)
                else:
                    self._stock_holders.append(StockHolderVO.from_alipay_dict(i))
    @property
    def ubos(self):
        return self._ubos

    @ubos.setter
    def ubos(self, value):
        if isinstance(value, list):
            self._ubos = list()
            for i in value:
                if isinstance(i, UboVO):
                    self._ubos.append(i)
                else:
                    self._ubos.append(UboVO.from_alipay_dict(i))
    @property
    def uc_code(self):
        return self._uc_code

    @uc_code.setter
    def uc_code(self, value):
        self._uc_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_address:
            if hasattr(self.business_address, 'to_alipay_dict'):
                params['business_address'] = self.business_address.to_alipay_dict()
            else:
                params['business_address'] = self.business_address
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.ever_org_name:
            if hasattr(self.ever_org_name, 'to_alipay_dict'):
                params['ever_org_name'] = self.ever_org_name.to_alipay_dict()
            else:
                params['ever_org_name'] = self.ever_org_name
        if self.industry_name:
            if hasattr(self.industry_name, 'to_alipay_dict'):
                params['industry_name'] = self.industry_name.to_alipay_dict()
            else:
                params['industry_name'] = self.industry_name
        if self.legal_representative:
            if hasattr(self.legal_representative, 'to_alipay_dict'):
                params['legal_representative'] = self.legal_representative.to_alipay_dict()
            else:
                params['legal_representative'] = self.legal_representative
        if self.local_tax_no:
            if hasattr(self.local_tax_no, 'to_alipay_dict'):
                params['local_tax_no'] = self.local_tax_no.to_alipay_dict()
            else:
                params['local_tax_no'] = self.local_tax_no
        if self.logoff_date:
            if hasattr(self.logoff_date, 'to_alipay_dict'):
                params['logoff_date'] = self.logoff_date.to_alipay_dict()
            else:
                params['logoff_date'] = self.logoff_date
        if self.managers:
            if isinstance(self.managers, list):
                for i in range(0, len(self.managers)):
                    element = self.managers[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.managers[i] = element.to_alipay_dict()
            if hasattr(self.managers, 'to_alipay_dict'):
                params['managers'] = self.managers.to_alipay_dict()
            else:
                params['managers'] = self.managers
        if self.norm_opr_project:
            if hasattr(self.norm_opr_project, 'to_alipay_dict'):
                params['norm_opr_project'] = self.norm_opr_project.to_alipay_dict()
            else:
                params['norm_opr_project'] = self.norm_opr_project
        if self.opr_status:
            if hasattr(self.opr_status, 'to_alipay_dict'):
                params['opr_status'] = self.opr_status.to_alipay_dict()
            else:
                params['opr_status'] = self.opr_status
        if self.oprt_end_date:
            if hasattr(self.oprt_end_date, 'to_alipay_dict'):
                params['oprt_end_date'] = self.oprt_end_date.to_alipay_dict()
            else:
                params['oprt_end_date'] = self.oprt_end_date
        if self.oprt_start_date:
            if hasattr(self.oprt_start_date, 'to_alipay_dict'):
                params['oprt_start_date'] = self.oprt_start_date.to_alipay_dict()
            else:
                params['oprt_start_date'] = self.oprt_start_date
        if self.org_actual_cptl:
            if hasattr(self.org_actual_cptl, 'to_alipay_dict'):
                params['org_actual_cptl'] = self.org_actual_cptl.to_alipay_dict()
            else:
                params['org_actual_cptl'] = self.org_actual_cptl
        if self.org_reg_addr:
            if hasattr(self.org_reg_addr, 'to_alipay_dict'):
                params['org_reg_addr'] = self.org_reg_addr.to_alipay_dict()
            else:
                params['org_reg_addr'] = self.org_reg_addr
        if self.org_reg_cptl:
            if hasattr(self.org_reg_cptl, 'to_alipay_dict'):
                params['org_reg_cptl'] = self.org_reg_cptl.to_alipay_dict()
            else:
                params['org_reg_cptl'] = self.org_reg_cptl
        if self.org_reg_cptl_curcy:
            if hasattr(self.org_reg_cptl_curcy, 'to_alipay_dict'):
                params['org_reg_cptl_curcy'] = self.org_reg_cptl_curcy.to_alipay_dict()
            else:
                params['org_reg_cptl_curcy'] = self.org_reg_cptl_curcy
        if self.org_reg_opr_scope:
            if hasattr(self.org_reg_opr_scope, 'to_alipay_dict'):
                params['org_reg_opr_scope'] = self.org_reg_opr_scope.to_alipay_dict()
            else:
                params['org_reg_opr_scope'] = self.org_reg_opr_scope
        if self.org_type:
            if hasattr(self.org_type, 'to_alipay_dict'):
                params['org_type'] = self.org_type.to_alipay_dict()
            else:
                params['org_type'] = self.org_type
        if self.org_website:
            if hasattr(self.org_website, 'to_alipay_dict'):
                params['org_website'] = self.org_website.to_alipay_dict()
            else:
                params['org_website'] = self.org_website
        if self.permit_opr_project:
            if hasattr(self.permit_opr_project, 'to_alipay_dict'):
                params['permit_opr_project'] = self.permit_opr_project.to_alipay_dict()
            else:
                params['permit_opr_project'] = self.permit_opr_project
        if self.registration_country:
            if hasattr(self.registration_country, 'to_alipay_dict'):
                params['registration_country'] = self.registration_country.to_alipay_dict()
            else:
                params['registration_country'] = self.registration_country
        if self.registration_date:
            if hasattr(self.registration_date, 'to_alipay_dict'):
                params['registration_date'] = self.registration_date.to_alipay_dict()
            else:
                params['registration_date'] = self.registration_date
        if self.registration_no:
            if hasattr(self.registration_no, 'to_alipay_dict'):
                params['registration_no'] = self.registration_no.to_alipay_dict()
            else:
                params['registration_no'] = self.registration_no
        if self.revoke_date:
            if hasattr(self.revoke_date, 'to_alipay_dict'):
                params['revoke_date'] = self.revoke_date.to_alipay_dict()
            else:
                params['revoke_date'] = self.revoke_date
        if self.stock_holders:
            if isinstance(self.stock_holders, list):
                for i in range(0, len(self.stock_holders)):
                    element = self.stock_holders[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.stock_holders[i] = element.to_alipay_dict()
            if hasattr(self.stock_holders, 'to_alipay_dict'):
                params['stock_holders'] = self.stock_holders.to_alipay_dict()
            else:
                params['stock_holders'] = self.stock_holders
        if self.ubos:
            if isinstance(self.ubos, list):
                for i in range(0, len(self.ubos)):
                    element = self.ubos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ubos[i] = element.to_alipay_dict()
            if hasattr(self.ubos, 'to_alipay_dict'):
                params['ubos'] = self.ubos.to_alipay_dict()
            else:
                params['ubos'] = self.ubos
        if self.uc_code:
            if hasattr(self.uc_code, 'to_alipay_dict'):
                params['uc_code'] = self.uc_code.to_alipay_dict()
            else:
                params['uc_code'] = self.uc_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VerifyInfoVO()
        if 'business_address' in d:
            o.business_address = d['business_address']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'ever_org_name' in d:
            o.ever_org_name = d['ever_org_name']
        if 'industry_name' in d:
            o.industry_name = d['industry_name']
        if 'legal_representative' in d:
            o.legal_representative = d['legal_representative']
        if 'local_tax_no' in d:
            o.local_tax_no = d['local_tax_no']
        if 'logoff_date' in d:
            o.logoff_date = d['logoff_date']
        if 'managers' in d:
            o.managers = d['managers']
        if 'norm_opr_project' in d:
            o.norm_opr_project = d['norm_opr_project']
        if 'opr_status' in d:
            o.opr_status = d['opr_status']
        if 'oprt_end_date' in d:
            o.oprt_end_date = d['oprt_end_date']
        if 'oprt_start_date' in d:
            o.oprt_start_date = d['oprt_start_date']
        if 'org_actual_cptl' in d:
            o.org_actual_cptl = d['org_actual_cptl']
        if 'org_reg_addr' in d:
            o.org_reg_addr = d['org_reg_addr']
        if 'org_reg_cptl' in d:
            o.org_reg_cptl = d['org_reg_cptl']
        if 'org_reg_cptl_curcy' in d:
            o.org_reg_cptl_curcy = d['org_reg_cptl_curcy']
        if 'org_reg_opr_scope' in d:
            o.org_reg_opr_scope = d['org_reg_opr_scope']
        if 'org_type' in d:
            o.org_type = d['org_type']
        if 'org_website' in d:
            o.org_website = d['org_website']
        if 'permit_opr_project' in d:
            o.permit_opr_project = d['permit_opr_project']
        if 'registration_country' in d:
            o.registration_country = d['registration_country']
        if 'registration_date' in d:
            o.registration_date = d['registration_date']
        if 'registration_no' in d:
            o.registration_no = d['registration_no']
        if 'revoke_date' in d:
            o.revoke_date = d['revoke_date']
        if 'stock_holders' in d:
            o.stock_holders = d['stock_holders']
        if 'ubos' in d:
            o.ubos = d['ubos']
        if 'uc_code' in d:
            o.uc_code = d['uc_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataIotdataDataDetailQueryModel(object):

    def __init__(self):
        self._business_id = None
        self._end_time = None
        self._point_id = None
        self._start_time = None
        self._sub_biz_id = None

    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def point_id(self):
        return self._point_id

    @point_id.setter
    def point_id(self, value):
        self._point_id = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def sub_biz_id(self):
        return self._sub_biz_id

    @sub_biz_id.setter
    def sub_biz_id(self, value):
        self._sub_biz_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_id:
            if hasattr(self.business_id, 'to_alipay_dict'):
                params['business_id'] = self.business_id.to_alipay_dict()
            else:
                params['business_id'] = self.business_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.point_id:
            if hasattr(self.point_id, 'to_alipay_dict'):
                params['point_id'] = self.point_id.to_alipay_dict()
            else:
                params['point_id'] = self.point_id
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.sub_biz_id:
            if hasattr(self.sub_biz_id, 'to_alipay_dict'):
                params['sub_biz_id'] = self.sub_biz_id.to_alipay_dict()
            else:
                params['sub_biz_id'] = self.sub_biz_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataIotdataDataDetailQueryModel()
        if 'business_id' in d:
            o.business_id = d['business_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'point_id' in d:
            o.point_id = d['point_id']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'sub_biz_id' in d:
            o.sub_biz_id = d['sub_biz_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateSceneUserSignModel(object):

    def __init__(self):
        self._alipay_school_id = None
        self._alipay_user_id = None
        self._cert_no = None
        self._cert_type = None
        self._name = None
        self._platform_channel = None
        self._sub_channel = None
        self._zim_id = None

    @property
    def alipay_school_id(self):
        return self._alipay_school_id

    @alipay_school_id.setter
    def alipay_school_id(self, value):
        self._alipay_school_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def platform_channel(self):
        return self._platform_channel

    @platform_channel.setter
    def platform_channel(self, value):
        self._platform_channel = value
    @property
    def sub_channel(self):
        return self._sub_channel

    @sub_channel.setter
    def sub_channel(self, value):
        self._sub_channel = value
    @property
    def zim_id(self):
        return self._zim_id

    @zim_id.setter
    def zim_id(self, value):
        self._zim_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_school_id:
            if hasattr(self.alipay_school_id, 'to_alipay_dict'):
                params['alipay_school_id'] = self.alipay_school_id.to_alipay_dict()
            else:
                params['alipay_school_id'] = self.alipay_school_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.platform_channel:
            if hasattr(self.platform_channel, 'to_alipay_dict'):
                params['platform_channel'] = self.platform_channel.to_alipay_dict()
            else:
                params['platform_channel'] = self.platform_channel
        if self.sub_channel:
            if hasattr(self.sub_channel, 'to_alipay_dict'):
                params['sub_channel'] = self.sub_channel.to_alipay_dict()
            else:
                params['sub_channel'] = self.sub_channel
        if self.zim_id:
            if hasattr(self.zim_id, 'to_alipay_dict'):
                params['zim_id'] = self.zim_id.to_alipay_dict()
            else:
                params['zim_id'] = self.zim_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateSceneUserSignModel()
        if 'alipay_school_id' in d:
            o.alipay_school_id = d['alipay_school_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'name' in d:
            o.name = d['name']
        if 'platform_channel' in d:
            o.platform_channel = d['platform_channel']
        if 'sub_channel' in d:
            o.sub_channel = d['sub_channel']
        if 'zim_id' in d:
            o.zim_id = d['zim_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotDapplyRefundCreateModel(object):

    def __init__(self):
        self._asset_apply_order_id = None
        self._memo = None

    @property
    def asset_apply_order_id(self):
        return self._asset_apply_order_id

    @asset_apply_order_id.setter
    def asset_apply_order_id(self, value):
        self._asset_apply_order_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_apply_order_id:
            if hasattr(self.asset_apply_order_id, 'to_alipay_dict'):
                params['asset_apply_order_id'] = self.asset_apply_order_id.to_alipay_dict()
            else:
                params['asset_apply_order_id'] = self.asset_apply_order_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotDapplyRefundCreateModel()
        if 'asset_apply_order_id' in d:
            o.asset_apply_order_id = d['asset_apply_order_id']
        if 'memo' in d:
            o.memo = d['memo']
        return o


